@@ -326,9 +326,6 @@ class Expression(operable.Operable):
     def __ne__(self, other):
         return Expression(self, "ne", other)
 
-    def __neg__(self):
-        return Expression(None, "-", self)
-
     def __bool__(self):
         raise ValidationError(
             "An expression cannot be used as a truth value. If you are "
@@ -377,7 +374,7 @@ class Expression(operable.Operable):
             left_str = (
                 str(self.left)
                 if isinstance(self.left, (int, float, str))
-                else self.left.latexRepr()
+                else self.left.latexRepr()  # type: ignore
             )
 
         if self.right is None:
@@ -386,7 +383,7 @@ class Expression(operable.Operable):
             right_str = (
                 str(self.right)
                 if isinstance(self.right, (int, float, str))
-                else self.right.latexRepr()
+                else self.right.latexRepr()  # type: ignore
             )
 
         data = self.data
@@ -575,7 +572,9 @@ class Expression(operable.Operable):
     def _validate_definition(
         self, control_stack: list[Set | Alias | ImplicitSet]
     ) -> None:
-        if not get_option("DOMAIN_VALIDATION"):
+        if not get_option("DOMAIN_VALIDATION") or not get_option(
+            "DOMAIN_VALIDATION"
+        ):
             return
 
         stack = []
