@@ -197,9 +197,6 @@ class Operation(operable.Operable):
     def __ne__(self, other):
         return expression.Expression(self, "ne", other)
 
-    def __neg__(self):
-        return expression.Expression(None, "-", self)
-
     def _replace_operations(self, output: str) -> str:
         output = output.replace("=l=", "<=")
         output = output.replace("=g=", ">=")
@@ -777,9 +774,6 @@ class Ord(operable.Operable):
     def __ne__(self, other):
         return expression.Expression(self, "ne", other)
 
-    def __neg__(self):
-        return expression.Expression(None, "-", self)
-
     def gamsRepr(self) -> str:
         """
         Representation of the Ord operation in GAMS language.
@@ -854,9 +848,6 @@ class Card(operable.Operable):
     def __ne__(self, other):  # type: ignore
         return expression.Expression(self, "ne", other)
 
-    def __neg__(self):
-        return expression.Expression(None, "-", self)
-
     def __bool__(self):
         raise ValidationError(
             "Card operation cannot be used as a truth value. Use len(<symbol>.records) instead."
