@@ -526,9 +526,7 @@ class NEOSServer(backend.Backend):
             "scrdir": scrdir,
             "scriptnext": os.path.join(scrdir, "gamsnext.sh"),
             "previouswork": 1,
-            "license": utils._get_license_path(
-                self.container.system_directory
-            ),
+            "license": self.container._license_path,
         }
 
         if self.container._network_license:
