@@ -46,6 +46,7 @@ if TYPE_CHECKING:
     )
     from gamspy._algebra.expression import Expression
     from gamspy._algebra.operation import Operation
+    from gamspy.math.matrix import Dim
 
 LOOPBACK = "127.0.0.1"
 IS_MIRO_INIT = os.getenv("MIRO", False)
@@ -81,18 +82,26 @@ def open_connection(
             f'curdir="{os.getcwd()}"\n'
         )
 
+    command = [
+        os.path.join(system_directory, "gams"),
+        "GAMSPY_JOB",
+        "pf",
+        initial_pf_file,
+    ]
+
+    certificate_path = os.path.join(utils.DEFAULT_DIR, "gamspy_cert.crt")
+    env = os.environ.copy()
+    if os.path.isfile(certificate_path):
+        env["GAMSLICECRT"] = certificate_path
+
     process = subprocess.Popen(
-        [
-            os.path.join(system_directory, "gams"),
-            "GAMSPY_JOB",
-            "pf",
-            initial_pf_file,
-        ],
+        command,
         text=True,
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
         errors="replace",
         start_new_session=platform.system() != "Windows",
+        env=env,
     )
 
     port_info = process.stdout.readline().strip()
@@ -132,13 +141,37 @@ def open_connection(
     return new_socket, process
 
 
-def get_system_directory(system_directory: str | None) -> str:
+def get_system_directory(system_directory: str | os.PathLike | None) -> str:
+    if isinstance(system_directory, os.PathLike):
+        system_directory = os.fspath(system_directory)
+
     if system_directory is not None:
         return system_directory
 
     return get_option("GAMS_SYSDIR")
 
 
+def get_options_file_name(solver: str, file_number: int) -> str:
+    """
+    Generates the option file name according to the `optfile` rules of GAMS.
+    Here are the rules:
+    1: solver.opt
+    2-9: solver.op<file_number>
+    10-99: solver.o<file_number>
+    >100: solver.<file_number>
+    """
+    if file_number == 1:
+        options_file_name = f"{solver}.opt"
+    elif file_number >= 2 and file_number <= 9:
+        options_file_name = f"{solver}.op{file_number}"
+    elif file_number >= 10 and file_number <= 99:
+        options_file_name = f"{solver}.o{file_number}"
+    else:
+        options_file_name = f"{solver}.{file_number}"
+
+    return options_file_name
+
+
 def check_response(response: bytes, job_name: str) -> None:
     GAMS_STATUS = {
         1: "Solver is to be called, the system should never return this number.",
@@ -204,11 +237,11 @@ class Container(gt.Container):
 
     Parameters
     ----------
-    load_from : str, Container, gt.Container, optional
+    load_from : str, os.PathLike, Container, gt.Container, optional
         Path to the GDX file to be loaded from, by default None
-    system_directory : str, optional
+    system_directory : str, os.PathLike, optional
         Path to the directory that holds the GAMS installation, by default None
-    working_directory : str, optional
+    working_directory : str, os.PathLike, optional
         Path to the working directory to store temporary files such .lst, .gms,
         .gdx, .g00 files.
     debugging_level : str, optional
@@ -227,9 +260,9 @@ class Container(gt.Container):
 
     def __init__(
         self,
-        load_from: str | Container | gt.Container | None = None,
-        system_directory: str | None = None,
-        working_directory: str | None = None,
+        load_from: str | os.PathLike | Container | gt.Container | None = None,
+        system_directory: str | os.PathLike | None = None,
+        working_directory: str | os.PathLike | None = None,
         debugging_level: Literal[
             "keep", "keep_on_error", "delete"
         ] = "keep_on_error",
@@ -250,7 +283,12 @@ class Container(gt.Container):
         self._unsaved_statements: list = []
 
         super().__init__(system_directory=system_directory)
-        self._license_path = utils._get_license_path(self.system_directory)
+        self._options = validation.validate_global_options(options)
+        if self._options.license is not None:
+            self._license_path = self._options.license
+        else:
+            self._license_path = utils._get_license_path(self.system_directory)
+
         self._network_license = self._is_network_license()
 
         self._debugging_level = debugging_level
@@ -269,8 +307,6 @@ class Container(gt.Container):
             system_directory=self.system_directory
         )
 
-        self._options = validation.validate_global_options(options)
-
         # needed for miro
         self._miro_input_symbols: list[str] = []
         self._miro_output_symbols: list[str] = []
@@ -288,6 +324,9 @@ class Container(gt.Container):
 
         self._is_restarted = False
         if load_from is not None:
+            if isinstance(load_from, os.PathLike):
+                load_from = os.fspath(load_from)
+
             if not isinstance(load_from, (str, gt.Container)):
                 raise ValidationError(
                     f"`load_from` must be of type str or Container but found {type(load_from)}"
@@ -631,7 +670,10 @@ class Container(gt.Container):
         strings += ["$offUNDF", "$offMulti"]
 
         if not IS_MIRO_INIT and MIRO_GDX_OUT:
-            strings.append(miro.get_unload_output_str(self))
+            if len(self._miro_output_symbols) == 0:
+                self.write(MIRO_GDX_OUT, symbol_names=[])
+            else:
+                strings.append(miro.get_unload_output_str(self))
 
         gams_string = "\n".join(strings)
 
@@ -693,7 +735,7 @@ class Container(gt.Container):
 
     def read(
         self,
-        load_from: str | Container | gt.Container,
+        load_from: str | os.PathLike | Container | gt.Container,
         symbol_names: list[str] | None = None,
         load_records: bool = True,
         mode: str | None = None,
@@ -705,7 +747,7 @@ class Container(gt.Container):
 
         Parameters
         ----------
-        load_from : str, Container, gt.Container
+        load_from : str, os.PathLike, Container, gt.Container
         symbol_names : List[str], optional
         load_records : bool
         mode : str, optional
@@ -723,6 +765,9 @@ class Container(gt.Container):
         True
 
         """
+        if isinstance(load_from, os.PathLike):
+            load_from = os.fspath(load_from)
+
         self._read(load_from, symbol_names, load_records, mode, encoding)
         self._synch_with_gams()
 
@@ -762,6 +807,61 @@ class Container(gt.Container):
             eps_to_zero=eps_to_zero,
         )
 
+    def writeSolverOptions(
+        self, solver: str, solver_options: dict, file_number: int = 1
+    ) -> None:
+        """
+        Writes solver options of the specified solver to the working directory.
+
+        Parameters
+        ----------
+        solver : str
+            Name of the solver.
+        solver_options : dict
+            Options of the specified solver.
+        file_number : int
+            Solver option file number. Equivalent to optfile option of GAMS. See https://gams.com/latest/docs/UG_GamsCall.html#GAMSAOoptfile for more details.
+
+        Examples
+        --------
+        >>> import gamspy as gp
+        >>> m = gp.Container()
+        >>> m.writeSolverOptions("conopt", solver_options={"rtmaxv": "1.e12"})
+
+        """
+        if file_number < 1:
+            raise ValidationError(
+                f"The smallest number `file_number` can get is 1 but received {file_number}"
+            )
+
+        options_file_name = os.path.join(
+            self.working_directory, get_options_file_name(solver, file_number)
+        )
+
+        with open(options_file_name, "w", encoding="utf-8") as solver_file:
+            for key, value in solver_options.items():
+                row = f"{key} {value}\n"
+                if solver.upper() in ("SHOT", "SOPLEX", "SCIP", "HIGHS"):
+                    row = f"{key} = {value}\n"
+
+                solver_file.write(row)
+
+        # The following solvers do not use the opt<solver>.def file
+        if solver.upper() in (
+            "HIGHS",
+            "SOPLEX",
+            "KESTREL",
+            "SCIP",
+            "SHOT",
+            "SOPLEX",
+        ):
+            return
+
+        if get_option("VALIDATION") and get_option("SOLVER_OPTION_VALIDATION"):
+            validation.validate_solver_options(
+                self.system_directory, options_file_name, solver
+            )
+
     def generateGamsString(self, show_raw: bool = False) -> str:
         """
         Generates the GAMS code
@@ -918,7 +1018,7 @@ class Container(gt.Container):
         domain: Sequence[Set | Alias | str] | Set | Alias | str | None = None,
         is_singleton: bool = False,
         records: Any | None = None,
-        domain_forwarding: bool = False,
+        domain_forwarding: bool | list[bool] = False,
         description: str = "",
         uels_on_axes: bool = False,
         is_miro_input: bool = False,
@@ -931,13 +1031,13 @@ class Container(gt.Container):
         ----------
         name : str, optional
             Name of the set. Name is autogenerated by default.
-        domain : list[Set | Alias | str] | Set | Alias | str, optional
+        domain : Sequence[Set | Alias | str] | Set | Alias | str, optional
             Domain of the set.
         is_singleton : bool, optional
             Whether the set is a singleton set. Singleton sets cannot contain more than one element.
         records : pd.DataFrame | np.ndarray | list, optional
             Records of the set.
-        domain_forwarding : bool, optional
+        domain_forwarding : bool | list[bool], optional
             Whether the set forwards the domain.
         description : str, optional
             Description of the set.
@@ -983,9 +1083,14 @@ class Container(gt.Container):
     def addParameter(
         self,
         name: str | None = None,
-        domain: Sequence[Set | Alias | str] | Set | Alias | str | None = None,
+        domain: Sequence[Set | Alias | str]
+        | Set
+        | Alias
+        | Dim
+        | str
+        | None = None,
         records: Any | None = None,
-        domain_forwarding: bool = False,
+        domain_forwarding: bool | list[bool] = False,
         description: str = "",
         uels_on_axes: bool = False,
         is_miro_input: bool = False,
@@ -999,11 +1104,11 @@ class Container(gt.Container):
         ----------
         name : str, optional
             Name of the parameter. Name is autogenerated by default.
-        domain : list[Set | Alias | str] | Set | Alias | str, optional
+        domain : Sequence[Set | Alias | str] | Set | Alias | Dim | str, optional
             Domain of the parameter.
         records : int | float | pd.DataFrame | np.ndarray | list, optional
             Records of the parameter.
-        domain_forwarding : bool, optional
+        domain_forwarding : bool | list[bool], optional
             Whether the parameter forwards the domain.
         description : str, optional
             Description of the parameter.
@@ -1052,9 +1157,14 @@ class Container(gt.Container):
         self,
         name: str | None = None,
         type: str = "free",
-        domain: Sequence[Set | Alias | str] | Set | Alias | str | None = None,
+        domain: Sequence[Set | Alias | str]
+        | Set
+        | Alias
+        | Dim
+        | str
+        | None = None,
         records: Any | None = None,
-        domain_forwarding: bool = False,
+        domain_forwarding: bool | list[bool] = False,
         description: str = "",
         uels_on_axes: bool = False,
         is_miro_output: bool = False,
@@ -1068,11 +1178,11 @@ class Container(gt.Container):
             Name of the variable. Name is autogenerated by default.
         type : str, optional
             Type of the variable. "free" by default.
-        domain : list[Set | Alias | str] | Set | Alias | str, optional
+        domain : Sequence[Set | Alias | str] | Set | Alias | Dim | str, optional
             Domain of the variable.
         records : Any, optional
             Records of the variable.
-        domain_forwarding : bool, optional
+        domain_forwarding : bool | list[bool], optional
             Whether the variable forwards the domain.
         description : str, optional
             Description of the variable.
@@ -1117,7 +1227,7 @@ class Container(gt.Container):
         domain: Sequence[Set | Alias | str] | Set | Alias | str | None = None,
         definition: Variable | Operation | Expression | None = None,
         records: Any | None = None,
-        domain_forwarding: bool = False,
+        domain_forwarding: bool | list[bool] = False,
         description: str = "",
         uels_on_axes: bool = False,
         is_miro_output: bool = False,
@@ -1132,13 +1242,13 @@ class Container(gt.Container):
             Name of the equation. Name is autogenerated by default.
         type : str
             Type of the equation. "regular" by default.
-        domain : list[Set | Alias | str] | Set | Alias | str, optional
+        domain : Sequence[Set | Alias | str] | Set | Alias | str, optional
             Domain of the variable.
         definition: Expression, optional
             Definition of the equation.
         records : Any, optional
             Records of the equation.
-        domain_forwarding : bool, optional
+        domain_forwarding : bool | list[bool], optional
             Whether the equation forwards the domain.
         description : str, optional
             Description of the equation.
