@@ -272,7 +272,7 @@ class Model:
 
     # Prefix for auto-generated symbols
     _generate_prefix = "autogenerated_"
-    _autogen_symbols: list[Variable | Equation] = []
+    _autogen_symbols: set[Variable | Equation] = set()
 
     def __init__(
         self,
@@ -280,9 +280,9 @@ class Model:
         name: str | None = None,
         description: str = "",
         problem: Problem | str = Problem.MIP,
-        equations: Sequence[Equation] = [],
+        equations: Sequence[Equation] | None = None,
         sense: Sense | str = Sense.FEASIBILITY,
-        objective: Variable | Expression | None = None,
+        objective: Variable | Expression | Operation | None = None,
         matches: dict[
             Equation | Sequence[Equation],
             Variable | Sequence[Variable],
@@ -292,12 +292,14 @@ class Model:
         external_module: str | None = None,
     ):
         self._auto_id = "m" + utils._get_unique_name()
+        if equations is None:
+            equations = []
 
         if name is not None:
             name = validation.validate_name(name)
             self.name = validation.validate_model_name(name)
         else:
-            self.name = self._auto_id
+            self.name = utils._get_symbol_name(prefix="m")
 
         self.description = description
 
@@ -832,8 +834,8 @@ class Model:
             f"{self.name}_objective",
             domain=[],
         )
-        self._autogen_symbols.append(variable.name)
-        self._autogen_symbols.append(equation.name)
+        self._autogen_symbols.add(variable.name)
+        self._autogen_symbols.add(equation.name)
 
         return variable, equation
 
@@ -960,10 +962,14 @@ class Model:
                     f"{self.name}.{MODEL_ATTR_OPTION_MAP[key]} = {value};\n"
                 )
             elif key in EXECUTION_OPTIONS:
-                if backend == "engine" and key == "loadpoint":
-                    value = os.path.relpath(
-                        value, self.container.working_directory
-                    )
+                if key == "loadpoint":
+                    if isinstance(value, os.PathLike):
+                        value = os.path.abspath(value)
+
+                    if backend == "engine":
+                        value = os.path.relpath(
+                            value, self.container.working_directory
+                        )
 
                 self.container._add_statement(
                     f"{EXECUTION_OPTIONS[key]} '{value}';\n"
@@ -1163,6 +1169,16 @@ class Model:
         modifiables: list[Parameter | ImplicitParameter],
         options: Options | None = None,
     ) -> None:
+        """
+        Instantiates a model instance. After calling freeze, only modifiables can be modified.
+
+        Parameters
+        ----------
+        modifiables : list[Parameter  |  ImplicitParameter]
+            Modifiable symbols.
+        options : Options | None, optional
+            GAMSPy options, by default None
+        """
         self._is_frozen = True
         if options is None:
             options = self.container._options
@@ -1196,9 +1212,9 @@ class Model:
         solver : str, optional
             Solver name
         options : Options, optional
-            GAMS options
+            GAMSPy options.
         solver_options : dict, optional
-            Solver options
+            Solver options.
         model_instance_options : ModelInstanceOptions, optional
             Options to solve a frozen model. This argument will be deprecated in GAMSPy 1.10.0. Please use freeze_options instead.
         freeze_options : FreezeOptions, optional
@@ -1243,15 +1259,16 @@ class Model:
         if solver is None:
             solver = utils.getDefaultSolvers(self.container.system_directory)[
                 str(self.problem).upper()
-            ]
+            ].lower()
         else:
             if not isinstance(solver, str):
                 raise TypeError(
                     f"`solver` argument must be of type `str` but given `{type(solver)}`"
                 )
+            solver = solver.lower()
 
-        if solver.upper() == "CONOPT":
-            solver = "CONOPT4"
+        if solver == "conopt":
+            solver = "conopt4"
 
         validation.validate_solver_args(
             self.container.system_directory,
@@ -1268,8 +1285,9 @@ class Model:
             options = self.container._options
 
         # Only for local until GAMS Engine and NEOS Server backends adopt the new GP_SolveLine option.
-        if solver == "local":
+        if backend == "local":
             frame = inspect.currentframe().f_back
+            assert isinstance(options, gp.Options)
             options._frame = frame
 
         if self._is_frozen:
@@ -1295,8 +1313,7 @@ class Model:
         self.container._add_statement(self._generate_solve_string() + "\n")
         self._create_model_attributes()
         options._set_solver_options(
-            system_directory=self.container.system_directory,
-            working_directory=self.container.working_directory,
+            container=self.container,
             solver=solver,
             problem=self.problem,
             solver_options=solver_options,
@@ -1422,15 +1439,25 @@ class Model:
         self,
         path: str,
         options: Options | None = None,
+        *,
         dump_gams_state: bool = False,
     ) -> None:
         """
-        Generates GAMS model under path/<model_name>.gms
+        Generates GAMS model under path/<model_name>.gms.
 
         Parameters
         ----------
         path : str
             Path to the directory which will contain the GAMS model.
+        options : Options | None, optional
+            GAMSPy options, by default None
+        dump_gams_state : bool, optional
+            Whether to dump the state as a GAMS save file, by default False
+
+        Raises
+        ------
+        ValidationError
+            In case the given options is not of type gp.Options.
         """
         if options is not None and not isinstance(options, gp.Options):
             raise ValidationError(
