@@ -66,7 +66,7 @@ from gamspy._database import (
     GamsParameter,
     GamsVariable,
 )
-from gamspy._options import FreezeOptions, Options, write_solver_options
+from gamspy._options import FreezeOptions, Options
 from gamspy.exceptions import (
     GamspyException,
     ValidationError,
@@ -179,7 +179,7 @@ class ModelInstance:
     container : Container
     model : Model
     modifiables : list[Parameter  |  ImplicitParameter]
-    freeze_options : Options | dict | None, optional
+    freeze_options : Options | None, optional
     """
 
     def __init__(
@@ -364,12 +364,7 @@ class ModelInstance:
         # write solver options file
         option_file = 0
         if solver_options:
-            write_solver_options(
-                self.container.system_directory,
-                self.container.working_directory,
-                solver,
-                solver_options,
-            )
+            self.container.writeSolverOptions(solver, solver_options)
             option_file = 1
 
         names_to_write = []
@@ -676,9 +671,7 @@ class ModelInstance:
             "sysdir": self.container.system_directory,
             "scrdir": scrdir,
             "scriptnext": os.path.join(scrdir, "gamsnext.sh"),
-            "license": utils._get_license_path(
-                self.container.system_directory
-            ),
+            "license": self.container._license_path,
             "solvercntr": self.solver_control_file,
         }
         if self.container._network_license:
