@@ -3,31 +3,20 @@ from __future__ import annotations
 import io
 import os
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Literal, Optional
+from typing import TYPE_CHECKING, Any, Literal, Optional, Union
 import warnings
 
-from gams.core.opt import (
-    new_optHandle_tp,
-    optCreateD,
-    optReadDefinition,
-    optClearMessages,
-    optReadParameterFile,
-    optFree,
-    optGetMessage,
-    GMS_SSSIZE,
-    optMessageCount,
-)
 from pydantic import BaseModel, ConfigDict
-from gamspy._config import get_option
 
 from gamspy.exceptions import ValidationError
 
 if TYPE_CHECKING:
+    from gamspy import Container
     from gamspy._model import Problem
     from types import FrameType
 
-MULTI_SOLVE_MAP = {"replace": 0, "merge": 1, "clear": 2}
 SOLVE_LINK_MAP = {"disk": 2, "memory": 5}
+SOLVE_LINK_MAP_REVERSE = dict(zip(SOLVE_LINK_MAP.values(), SOLVE_LINK_MAP.keys()))
 
 # GAMSPy to GAMS option mapping
 OPTION_MAP = {
@@ -46,8 +35,10 @@ OPTION_MAP = {
     "rmip": "rmip",
     "rmiqcp": "rmiqcp",
     "rmpec": "rmpec",
+    "license": "license",
     "allow_suffix_in_equation": "suffixalgebravars",
     "allow_suffix_in_limited_variables": "suffixdlvars",
+    "append_to_log_file": "appendLog",
     "basis_detection_threshold": "bratio",
     "compile_error_limit": "cerr",
     "domain_violation_limit": "domlim",
@@ -82,6 +73,7 @@ OPTION_MAP = {
     "zero_rounding_threshold": "zerores",
     "report_underflow": "zeroresrep",
 }
+OPTION_MAP_REVERSE = dict(zip(OPTION_MAP.values(), OPTION_MAP.keys()))
 
 MODEL_ATTR_OPTION_MAP = {
     "generate_name_dict": "dictfile",
@@ -139,6 +131,8 @@ class Options(BaseModel):
         Flag to allow variables with suffixes in model algebra
     allow_suffix_in_limited_variables: bool | None
         Flag to allow **domain limited variables** with suffixes in model
+    append_to_log_file: bool | None
+        Setting this option to True means that the log file will be appended to and not overwritten (replaced).
     basis_detection_threshold: float | None
         Basis detection threshold
     compile_error_limit: int = 1
@@ -199,9 +193,11 @@ class Options(BaseModel):
         Iteration limit of solver
     keep_temporary_files: bool = False
         Controls keeping or deletion of process directory and scratch files
+    license: str | None
+        Absolute path of the license.
     listing_file: str | None
         Listing file name
-    loadpoint: str | None
+    loadpoint: os.PathLike | str | None
         Path to the loadpoint GDX file that contains starting point records.
     log_file: str | None
         Log file name
@@ -235,6 +231,12 @@ class Options(BaseModel):
         Monitor the memory used by the GAMS process tree
     profile: int | None
         Execution profiling
+
+        * **Option 0**: Do not profile.
+
+        * **Option 1**: Minimum profiling.
+
+        * **Option n**: Profiling depth for nested control structures.
     profile_file: str
         Write profile information to this file
     profile_tolerance: float | None
@@ -320,6 +322,7 @@ class Options(BaseModel):
     rmpec: Optional[str] = None
     allow_suffix_in_equation: Optional[bool] = None
     allow_suffix_in_limited_variables: Optional[bool] = None
+    append_to_log_file: Optional[bool] = None
     basis_detection_threshold: Optional[float] = None
     compile_error_limit: Optional[int] = None
     domain_violation_limit: Optional[int] = None
@@ -337,8 +340,9 @@ class Options(BaseModel):
     hold_fixed_variables: Optional[bool] = None
     iteration_limit: Optional[int] = None
     keep_temporary_files: Optional[int] = None
+    license: Optional[str] = None
     listing_file: Optional[str] = None
-    loadpoint: Optional[str] = None
+    loadpoint: Optional[Union[str, os.PathLike]] = None
     log_file: Optional[str] = None
     variable_listing_limit: int = 0
     equation_listing_limit: int = 0
@@ -374,6 +378,49 @@ class Options(BaseModel):
         self._solver_options_file: str = "0"
         self._frame: FrameType | None = None
 
+    @staticmethod
+    def fromGams(options: dict) -> Options:
+        """
+        Generates a gp.Options object from a dictionary of GAMS options 
+        where keys are the GAMS option names.
+
+        Parameters
+        ----------
+        options : dict
+            GAMS options.
+
+        Returns
+        -------
+        Options
+            Generated GAMSPy options
+
+        Raises
+        ------
+        ValidationError
+            In case the option is not supported in GAMSPy.
+
+        Examples
+        --------
+        >>> import gamspy as gp
+        >>> m = gp.Container()
+        >>> options = gp.Options.fromGams({"reslim": 5})
+
+        """
+        gamspy_options = {}
+        for key, value in options.items():
+            if key.lower() in OPTION_MAP_REVERSE:
+                if key.lower() == "solvelink":
+                    try:
+                        value = SOLVE_LINK_MAP_REVERSE[value]
+                    except KeyError:
+                        raise ValidationError(f"`{value}` is not a valid value for `{key}`. Possible values are 2 and 5.")
+
+                gamspy_options[OPTION_MAP_REVERSE[key.lower()]] = value
+            else:
+                raise ValidationError(f"`{key}` is not a supported option in GAMSPy.")
+
+        return Options(**gamspy_options) 
+
     def _get_gams_compatible_options(
         self, output: io.TextIOWrapper | None = None
     ) -> dict:
@@ -390,10 +437,6 @@ class Options(BaseModel):
                 "on" if allows_suffix else "off"
             )
 
-        if "merge_strategy" in gamspy_options:
-            strategy = gamspy_options["merge_strategy"]
-            gamspy_options["merge_strategy"] = MULTI_SOLVE_MAP[strategy]
-
         if "solve_link_type" in gamspy_options:
             link_type = gamspy_options["solve_link_type"]
             gamspy_options["solve_link_type"] = SOLVE_LINK_MAP[link_type]
@@ -438,8 +481,7 @@ class Options(BaseModel):
 
     def _set_solver_options(
         self,
-        system_directory: str,
-        working_directory: str,
+        container: Container,
         solver: str,
         problem: Problem,
         solver_options: dict | None,
@@ -449,9 +491,7 @@ class Options(BaseModel):
         self._problem = str(problem)
 
         if solver_options:
-            write_solver_options(
-                system_directory, working_directory, solver, solver_options
-            )
+            container.writeSolverOptions(solver, solver_options)
             self._solver_options_file = "1"
         else:
             self._solver_options_file = "0"
@@ -669,111 +709,3 @@ class ConvertOptions(BaseModel):
     Reform: Optional[int] = None
     SkipNRows: Optional[int] = None
     Width: Optional[int] = None
-
-
-def write_solver_options(
-    system_directory: str,
-    working_directory: str,
-    solver: str,
-    solver_options: dict,
-) -> None:
-    options_file_name = os.path.join(
-        working_directory, f"{solver.lower()}.opt"
-    )
-    with open(options_file_name, "w", encoding="utf-8") as solver_file:
-        for key, value in solver_options.items():
-            row = f"{key} {value}\n"
-            if solver.upper() in ("SHOT", "SOPLEX", "SCIP", "HIGHS"):
-                row = f"{key} = {value}\n"
-
-            solver_file.write(row)
-
-    # The following solvers do not use the opt<solver>.def file
-    if solver.upper() in (
-        "HIGHS",
-        "SOPLEX",
-        "KESTREL",
-        "SCIP",
-        "SHOT",
-        "SOPLEX",
-    ):
-        return
-
-    if get_option("VALIDATION") and get_option("SOLVER_OPTION_VALIDATION"):
-        validate_solver_options(system_directory, options_file_name, solver)
-
-
-def get_def_file(system_directory: str, solver: str) -> str:
-    solver_name = solver.upper()
-    def_file_path = os.path.join(system_directory, f"opt{solver.lower()}.def")
-
-    if solver_name == "CONOPT4":
-        return os.path.join(system_directory, "optconopt.def")
-
-    if solver_name == "EXAMINER2":
-        return os.path.join(system_directory, "optexaminer.def")
-    
-    if solver_name == "IPOPTH":
-        return os.path.join(system_directory, "optipopt.def")
-
-    return def_file_path
-
-
-def validate_solver_options(
-    system_directory: str, options_file_name: str, solver: str
-) -> None:
-    if not get_option("VALIDATION"):
-        return
-
-    option_handle = new_optHandle_tp()
-    rc, msg = optCreateD(option_handle, system_directory, GMS_SSSIZE)
-
-    # Return code 0 means there is an error. Weird but this is what we have to work with.
-    if rc == 0:
-        raise RuntimeError(msg)
-
-    # Check the validity of the .def file.
-    solver_def_file = get_def_file(system_directory, solver)
-    if optReadDefinition(option_handle, solver_def_file):
-        msg_list = []
-        for i in range(optMessageCount(option_handle)):
-            msg_list.append(optGetMessage(option_handle, i + 1))
-
-        raise RuntimeError(
-            f"Error while processing {solver_def_file}. Log messages: {msg_list}"
-        )
-
-    optClearMessages(option_handle)
-
-    # Check the validity of the parameters 
-    if optReadParameterFile(option_handle, options_file_name):
-        raise RuntimeError(f"Error while reading {options_file_name}")
-
-    msg_list = []
-    for i in range(optMessageCount(option_handle)):
-        msg_list.append(optGetMessage(option_handle, i + 1))
-
-    optClearMessages(option_handle)
-    optFree(option_handle)
-
-    if msg_list:
-        error_messages = []
-        for message in msg_list:
-            # optMsgInputEcho    = 0,
-            # optMsgHelp         = 1,
-            # optMsgDefineError  = 2,
-            # optMsgValueError   = 3,
-            # optMsgValueWarning = 4,
-            # optMsgDeprecated   = 5,
-            # optMsgFileEnter    = 6,
-            # optMsgFileLeave    = 7,
-            # optMsgTooManyMsgs  = 8,
-            # optMsgUserError    = 9
-            if message[1] not in (6, 7):
-                error_messages.append(message[0])
-
-        if error_messages:
-            error_message = "\n".join(error_messages)
-            raise ValidationError(
-                f"Error while reading the parameter file: \n\n{error_message}"
-            )
