@@ -24,169 +24,156 @@ if TYPE_CHECKING:
 
     from gamspy import Alias, Container
     from gamspy._algebra.expression import Expression
-    from gamspy._symbols.implicits.implicit_set import ImplicitSet
+    from gamspy._symbols.implicits import ImplicitParameter, ImplicitSet
     from gamspy._types import EllipsisType, OperableType
+    from gamspy.math import Dim
     from gamspy.math.misc import MathOp
 
 
 class SetMixin:
     @property
-    def pos(self: Set | Alias) -> Expression:
+    def pos(self: Set | Alias) -> ImplicitParameter:
         """
         Element position in the current set, starting with 1.
 
         Returns
         -------
-        Expression
+        ImplicitParameter
 
         Examples
         --------
         >>> import gamspy as gp
         >>> m = gp.Container()
         >>> i = gp.Set(m, name="i", records=["seattle", "san-diego", "new-york"], description="canning plants")
-        >>> attr = gp.Parameter(m, "attr", domain = [i, "*"], description = "Set position values")
-        >>> attr[i,"position"]  =  i.pos
-        >>> attr.records.values.tolist()
+        >>> i.pos.records.values.tolist()
         [['seattle', 'position', 1.0], ['san-diego', 'position', 2.0], ['new-york', 'position', 3.0]]
 
         """
-        return expression.Expression(self, ".", "pos")
+        return implicits.ImplicitParameter(self, f"{self.name}.pos")
 
     @property
-    def ord(self: Set | Alias) -> Expression:
+    def ord(self: Set | Alias) -> ImplicitParameter:
         """
         Same as .pos but for ordered sets only.
 
         Returns
         -------
-        Expression
+        ImplicitParameter
 
         Examples
         --------
         >>> import gamspy as gp
         >>> m = gp.Container()
         >>> i = gp.Set(m, name="i", records=["seattle", "san-diego", "new-york"], description="canning plants")
-        >>> attr = gp.Parameter(m, "attr", domain = [i, "*"], description = "Set order values")
-        >>> attr[i,"order"]  =  i.ord
-        >>> attr.records.values.tolist()
+        >>> i.ord.records.values.tolist()
         [['seattle', 'order', 1.0], ['san-diego', 'order', 2.0], ['new-york', 'order', 3.0]]
 
         """
-        return expression.Expression(self, ".", "ord")
+        return implicits.ImplicitParameter(self, f"{self.name}.ord")
 
     @property
-    def off(self: Set | Alias) -> Expression:
+    def off(self: Set | Alias) -> ImplicitParameter:
         """
         Element position in the current set minus 1. So .off = .pos - 1
 
         Returns
         -------
-        Expression
+        ImplicitParameter
 
         Examples
         --------
         >>> import gamspy as gp
         >>> m = gp.Container()
         >>> i = gp.Set(m, name="i", records=["seattle", "san-diego", "new-york"], description="canning plants")
-        >>> attr = gp.Parameter(m, "attr", domain = [i, "*"], description = "Set off values")
-        >>> attr[i,"off"]  =  i.off
-        >>> attr.records.values.tolist()
+        >>> i.off.records.values.tolist()
         [['san-diego', 'off', 1.0], ['new-york', 'off', 2.0]]
 
         """
-        return expression.Expression(self, ".", "off")
+        return implicits.ImplicitParameter(self, f"{self.name}.off")
 
     @property
-    def rev(self: Set | Alias) -> Expression:
+    def rev(self: Set | Alias) -> ImplicitParameter:
         """
         Reverse element position in the current set, so the value for
         the last element is 0, the value for the penultimate is 1, etc.
 
         Returns
         -------
-        Expression
+        ImplicitParameter
 
         Examples
         --------
         >>> import gamspy as gp
         >>> m = gp.Container()
         >>> i = gp.Set(m, name="i", records=["seattle", "san-diego", "new-york"], description="canning plants")
-        >>> attr = gp.Parameter(m, "attr", domain = [i, "*"], description = "Set reverse values")
-        >>> attr[i,"reverse"]  =  i.rev
-        >>> attr.records.values.tolist()
+        >>> i.rev.records.values.tolist()
         [['seattle', 'reverse', 2.0], ['san-diego', 'reverse', 1.0]]
 
         """
-        return expression.Expression(self, ".", "rev")
+        return implicits.ImplicitParameter(self, f"{self.name}.rev")
 
     @property
-    def uel(self: Set | Alias) -> Expression:
+    def uel(self: Set | Alias) -> ImplicitParameter:
         """
         Element position in the unique element list.
 
         Returns
         -------
-        Expression
+        ImplicitParameter
 
         Examples
         --------
         >>> import gamspy as gp
         >>> m = gp.Container()
         >>> i = gp.Set(m, name="i", records=["seattle", "san-diego", "new-york"], description="canning plants")
-        >>> attr = gp.Parameter(m, "attr", domain = [i, "*"], description = "Set uel_pos values")
-        >>> attr[i,"uel_position"]  =  i.uel
-        >>> attr.records.values.tolist()
+        >>> i.uel.records.values.tolist()
         [['seattle', 'uel_position', 1.0], ['san-diego', 'uel_position', 2.0], ['new-york', 'uel_position', 3.0]]
 
         """
-        return expression.Expression(self, ".", "uel")
+        return implicits.ImplicitParameter(self, f"{self.name}.uel")
 
     @property
-    def len(self: Set | Alias) -> Expression:
+    def len(self: Set | Alias) -> ImplicitParameter:
         """
         Length of the set element name (a count of the number of characters).
 
         Returns
         -------
-        Expression
+        ImplicitParameter
 
         Examples
         --------
         >>> import gamspy as gp
         >>> m = gp.Container()
         >>> i = gp.Set(m, name="i", records=["seattle", "san-diego", "new-york"], description="canning plants")
-        >>> attr = gp.Parameter(m, "attr", domain = [i, "*"], description = "Set length values")
-        >>> attr[i,"length"]  =  i.len
-        >>> attr.records.values.tolist()
+        >>> i.len.records.values.tolist()
         [['seattle', 'length', 7.0], ['san-diego', 'length', 9.0], ['new-york', 'length', 8.0]]
 
         """
-        return expression.Expression(self, ".", "len")
+        return implicits.ImplicitParameter(self, f"{self.name}.len")
 
     @property
-    def tlen(self: Set | Alias) -> Expression:
+    def tlen(self: Set | Alias) -> ImplicitParameter:
         """
         Length of the set element text (a count of the number of characters).
 
         Returns
         -------
-        Expression
+        ImplicitParameter
 
         Examples
         --------
         >>> import gamspy as gp
         >>> m = gp.Container()
         >>> i = gp.Set(m, name="i", records=[("seattle", "Wisconsin"), ("san-diego", ""), ("new-york", " ")], description="canning plants")
-        >>> attr = gp.Parameter(m, "attr", domain = [i, "*"], description = "Set element text length values")
-        >>> attr[i,"text_length"]  =  i.tlen
-        >>> attr.records.values.tolist()
+        >>> i.tlen.records.values.tolist()
         [['seattle', 'text_length', 9.0], ['new-york', 'text_length', 1.0]]
 
         """
-        return expression.Expression(self, ".", "tlen")
+        return implicits.ImplicitParameter(self, f"{self.name}.tlen")
 
     @property
-    def val(self: Set | Alias) -> Expression:
+    def val(self: Set | Alias) -> ImplicitParameter:
         """
         If a set element is a number, this attribute gives the value of the number.
         For extended range arithmetic symbols, the symbols are reproduced.
@@ -195,23 +182,21 @@ class SetMixin:
 
         Returns
         -------
-        Expression
+        ImplicitParameter
 
         Examples
         --------
         >>> import gamspy as gp
         >>> m = gp.Container()
         >>> i = gp.Set(m, name="i", records=["12", "20", "-13.4"], description="canning plants")
-        >>> attr = gp.Parameter(m, "attr", domain = [i, "*"], description = "Set val values")
-        >>> attr[i,"value"]  =  i.val
-        >>> attr.records.values.tolist()
+        >>> i.val.records.values.tolist()
         [['12', 'value', 12.0], ['20', 'value', 20.0], ['-13.4', 'value', -13.4]]
 
         """
-        return expression.Expression(self, ".", "val")
+        return implicits.ImplicitParameter(self, f"{self.name}.val")
 
     @property
-    def tval(self: Set | Alias) -> Expression:
+    def tval(self: Set | Alias) -> ImplicitParameter:
         """
         If a set element text is a number, this attribute gives the value of the number.
         For extended range arithmetic symbols, the symbols are reproduced.
@@ -220,64 +205,58 @@ class SetMixin:
 
         Returns
         -------
-        Expression
+        ImplicitParameter
 
         Examples
         --------
         >>> import gamspy as gp
         >>> m = gp.Container()
         >>> i = gp.Set(m, name="i", records=[("seattle", "12"), ("san-diego", ""), ("new-york", "-13.4")], description="canning plants")
-        >>> attr = gp.Parameter(m, "attr", domain = [i, "*"], description = "Set text values")
-        >>> attr[i,"text_value"]  =  i.tval
-        >>> attr.records.values.tolist()
+        >>> i.tval.records.values.tolist()
         [['seattle', 'text_value', 12.0], ['new-york', 'text_value', -13.4]]
 
         """
-        return expression.Expression(self, ".", "tval")
+        return implicits.ImplicitParameter(self, f"{self.name}.tval")
 
     @property
-    def first(self: Set | Alias) -> Expression:
+    def first(self: Set | Alias) -> ImplicitParameter:
         """
         Returns 1 for the first set element, otherwise 0.
 
         Returns
         -------
-        Expression
+        ImplicitParameter
 
         Examples
         --------
         >>> import gamspy as gp
         >>> m = gp.Container()
         >>> i = gp.Set(m, name="i", records=["seattle", "san-diego", "new-york"], description="canning plants")
-        >>> attr = gp.Parameter(m, "attr", domain = [i, "*"])
-        >>> attr[i,"is_first"]  =  i.first
-        >>> attr.records.values.tolist()
+        >>> i.first.records.values.tolist()
         [['seattle', 'is_first', 1.0]]
 
         """
-        return expression.Expression(self, ".", "first")
+        return implicits.ImplicitParameter(self, f"{self.name}.first")
 
     @property
-    def last(self: Set | Alias) -> Expression:
+    def last(self: Set | Alias) -> ImplicitParameter:
         """
         Returns 1 for the last set element, otherwise 0.
 
         Returns
         -------
-        Expression
+        ImplicitParameter
 
         Examples
         --------
         >>> import gamspy as gp
         >>> m = gp.Container()
         >>> i = gp.Set(m, name="i", records=["seattle", "san-diego", "new-york"], description="canning plants")
-        >>> attr = gp.Parameter(m, "attr", domain = [i, "*"])
-        >>> attr[i,"is_last"]  =  i.last
-        >>> attr.records.values.tolist()
+        >>> i.last.records.values.tolist()
         [['new-york', 'is_last', 1.0]]
 
         """
-        return expression.Expression(self, ".", "last")
+        return implicits.ImplicitParameter(self, f"{self.name}.last")
 
     def lag(
         self,
@@ -438,7 +417,7 @@ class Set(gt.Set, operable.Operable, Symbol, SetMixin):
         Whether the set is a singleton set. Singleton sets cannot contain more than one element.
     records : pd.DataFrame | np.ndarray | list, optional
         Records of the set.
-    domain_forwarding : bool, optional
+    domain_forwarding : bool | list[bool], optional
         Whether the set forwards the domain.
     description : str, optional
         Description of the set.
@@ -462,11 +441,20 @@ class Set(gt.Set, operable.Operable, Symbol, SetMixin):
         cls,
         container: Container,
         name: str,
-        domain: Sequence[Set | Alias | str] | Set | Alias | str = [],
+        domain: Sequence[Set | Alias | str] | Set | Alias | str | None = None,
         is_singleton: bool = False,
         records: Any | None = None,
         description: str = "",
     ):
+        if domain is None:
+            domain = ["*"]
+
+        if isinstance(domain, (gp.Set, gp.Alias, str)):
+            domain = [domain]
+
+        if isinstance(domain, gp.math.Dim):
+            domain = gp.math._generate_dims(container, domain.dims)
+
         # create new symbol object
         obj = Set.__new__(
             cls,
@@ -490,6 +478,7 @@ class Set(gt.Set, operable.Operable, Symbol, SetMixin):
         obj._records = records
         obj._modified = True
         obj._is_singleton = is_singleton
+        obj._domain_violations = None
 
         # typing
         obj._gams_type = GMS_DT_SET
@@ -503,6 +492,7 @@ class Set(gt.Set, operable.Operable, Symbol, SetMixin):
         obj.container._add_statement(obj)
         obj._synchronize = True
         obj._metadata = dict()
+        obj._winner = "python"
 
         # miro support
         obj._is_miro_input = False
@@ -514,10 +504,15 @@ class Set(gt.Set, operable.Operable, Symbol, SetMixin):
         cls,
         container: Container | None = None,
         name: str | None = None,
-        domain: Sequence[Set | Alias | str] | Set | Alias | str | None = None,
+        domain: Sequence[Set | Alias | str]
+        | Set
+        | Alias
+        | str
+        | Dim
+        | None = None,
         is_singleton: bool = False,
         records: Any | None = None,
-        domain_forwarding: bool = False,
+        domain_forwarding: bool | list[bool] = False,
         description: str = "",
         uels_on_axes: bool = False,
         is_miro_input: bool = False,
@@ -558,10 +553,15 @@ class Set(gt.Set, operable.Operable, Symbol, SetMixin):
         self,
         container: Container | None = None,
         name: str | None = None,
-        domain: Sequence[Set | Alias | str] | Set | Alias | str | None = None,
+        domain: Sequence[Set | Alias | str]
+        | Set
+        | Alias
+        | str
+        | Dim
+        | None = None,
         is_singleton: bool = False,
         records: Any | None = None,
-        domain_forwarding: bool = False,
+        domain_forwarding: bool | list[bool] = False,
         description: str = "",
         uels_on_axes: bool = False,
         is_miro_input: bool = False,
@@ -573,8 +573,11 @@ class Set(gt.Set, operable.Operable, Symbol, SetMixin):
 
         self._is_miro_input = is_miro_input
         self._is_miro_output = is_miro_output
+        self._is_miro_symbol = is_miro_input or is_miro_output
+        self._domain_violations = None
 
         self._synchronize = True
+        self._winner = "python"
 
         # domain handling
         if domain is None:
@@ -647,7 +650,7 @@ class Set(gt.Set, operable.Operable, Symbol, SetMixin):
                 if is_miro_input or is_miro_output:
                     name = name.lower()  # type: ignore
             else:
-                name = "s" + utils._get_unique_name() + "gpauto"
+                name = utils._get_symbol_name(prefix="s")
 
             self._singleton_check(is_singleton, records, domain)
             previous_state = container._options.miro_protect
@@ -676,7 +679,8 @@ class Set(gt.Set, operable.Operable, Symbol, SetMixin):
             if records is not None:
                 self.setRecords(records, uels_on_axes=uels_on_axes)
             else:
-                self.modified = False
+                if not self._is_miro_symbol:
+                    self.modified = False
                 self.container._synch_with_gams(
                     gams_to_gamspy=self._is_miro_input
                 )
@@ -721,7 +725,9 @@ class Set(gt.Set, operable.Operable, Symbol, SetMixin):
 
         return 0
 
-    def __getitem__(self, indices: Sequence | str) -> implicits.ImplicitSet:
+    def __getitem__(
+        self, indices: Sequence | str | int | EllipsisType | slice
+    ) -> implicits.ImplicitSet:
         domain = validation.validate_domain(self, indices)
 
         return implicits.ImplicitSet(self, name=self.name, domain=domain)
@@ -856,6 +862,13 @@ class Set(gt.Set, operable.Operable, Symbol, SetMixin):
 
         super().setRecords(records, uels_on_axes)
 
+        if gp.get_option("DROP_DOMAIN_VIOLATIONS"):
+            if self.hasDomainViolations():
+                self._domain_violations = self.getDomainViolations()
+                self.dropDomainViolations()
+            else:
+                self._domain_violations = None
+
         self.container._synch_with_gams(gams_to_gamspy=self._is_miro_input)
         self._winner = "python"
 
