@@ -1,9 +1,22 @@
 from __future__ import annotations
 
 import io
+import os
+import re
 from collections.abc import Iterable, Sequence
-from typing import TYPE_CHECKING, Any, Literal
+from typing import TYPE_CHECKING, Literal
 
+from gams.core.opt import (
+    GMS_SSSIZE,
+    new_optHandle_tp,
+    optClearMessages,
+    optCreateD,
+    optFree,
+    optGetMessage,
+    optMessageCount,
+    optReadDefinition,
+    optReadParameterFile,
+)
 from gams.transfer._internals import GAMS_SYMBOL_MAX_LENGTH
 
 import gamspy._symbols as symbols
@@ -26,6 +39,8 @@ if TYPE_CHECKING:
     )
     from gamspy._types import EllipsisType
 
+NAME_MATCH_REGEX = re.compile(r"^[a-zA-Z][a-zA-Z0-9_]{0,62}$")
+
 RESERVED_WORDS = (
     "abort",
     "acronym",
@@ -166,7 +181,7 @@ def validate_dimension(
     | ImplicitParameter
     | ImplicitVariable
     | Operation,
-    domain: list[Set | Alias | ImplicitSet | str],
+    domain: Sequence[Set | Alias | ImplicitSet | str],
 ) -> None:
     dimension = get_dimension(domain)
 
@@ -240,7 +255,7 @@ def _get_ellipsis_range(domain, given_domain):
 
 
 def _expand_ellipsis_slice(
-    domain: list[Set | Alias | str],
+    domain: Sequence[Set | Alias | str],
     indices: Sequence[Set | Alias | str | EllipsisType | slice],
 ) -> Sequence[Set | Alias | str]:
     if len(domain) == 0:
@@ -308,7 +323,7 @@ def validate_domain(
     offset = 0
     for given in domain:
         try:
-            given_dim = given.dimension
+            given_dim = given.dimension  # type: ignore
         except AttributeError:
             given_dim = 1
         actual = symbol.domain[offset]
@@ -348,7 +363,7 @@ def validate_container(
     | ImplicitParameter
     | ImplicitVariable
     | Operation,
-    domain: list[str | Set | Alias],
+    domain: Sequence[str | Set | Alias],
 ):
     for set in domain:
         if (
@@ -365,8 +380,11 @@ def validate_name(word: str) -> str:
     if not get_option("VALIDATION"):
         return word
 
+    if word == "":
+        raise ValueError("Symbol name cannot be an empty string.")
+
     if not isinstance(word, str):
-        raise TypeError("Symbol name must be type str")
+        raise TypeError("Symbol name must be type str.")
 
     if word.lower() in RESERVED_WORDS:
         raise ValidationError(
@@ -379,6 +397,13 @@ def validate_name(word: str) -> str:
             "Name cannot end with one of the reserved words. `gpauto` is a reserverd word."
         )
 
+    if not re.match(NAME_MATCH_REGEX, word):
+        raise ValidationError(
+            f"`{word}` is an invalid GAMSPy symbol name. "
+            "GAMSPy symbol names can only contain alphanumeric characters "
+            "(letters and numbers) and the '_' character. They must start "
+            "with a letter. They also shouldn't be more than 63 characters."
+        )
     return word
 
 
@@ -541,8 +566,12 @@ def validate_solver_args(
             f"`{solver}` is not a valid solver for GAMS Engine."
         )
 
-    if backend == "local":
-        # No need to check whether the solver is installed on client's machine for NEOS or ENGINE.
+    # No need to check whether the solver is installed on client's machine for NEOS or ENGINE.
+    if (
+        backend == "local"
+        and get_option("VALIDATION")
+        and get_option("SOLVER_VALIDATION")
+    ):
         installed_solvers = utils.getInstalledSolvers(system_directory)
         if solver.upper() not in installed_solvers:
             raise ValidationError(
@@ -587,10 +616,12 @@ def validate_equations(model: Model) -> None:
             )
 
 
-def validate_global_options(options: Any) -> Options:
+def validate_global_options(options: Options | None) -> Options:
     if not get_option("VALIDATION"):
         if options is None:
             return Options()
+        elif isinstance(options, dict):
+            return Options.fromGams(options)
 
         return options
 
@@ -615,3 +646,79 @@ def validate_global_options(options: Any) -> Options:
         return Options()
 
     return options
+
+
+def _get_def_file(system_directory: str, solver: str) -> str:
+    solver_name = solver.upper()
+    def_file_path = os.path.join(system_directory, f"opt{solver.lower()}.def")
+
+    if solver_name == "CONOPT4":
+        return os.path.join(system_directory, "optconopt.def")
+
+    if solver_name == "EXAMINER2":
+        return os.path.join(system_directory, "optexaminer.def")
+
+    if solver_name == "IPOPTH":
+        return os.path.join(system_directory, "optipopt.def")
+
+    return def_file_path
+
+
+def validate_solver_options(
+    system_directory: str, options_file_name: str, solver: str
+) -> None:
+    if not get_option("VALIDATION"):
+        return
+
+    option_handle = new_optHandle_tp()
+    rc, msg = optCreateD(option_handle, system_directory, GMS_SSSIZE)
+
+    # Return code 0 means there is an error. Weird but this is what we have to work with.
+    if rc == 0:
+        raise RuntimeError(msg)
+
+    # Check the validity of the .def file.
+    solver_def_file = _get_def_file(system_directory, solver)
+    if optReadDefinition(option_handle, solver_def_file):
+        msg_list = []
+        for i in range(optMessageCount(option_handle)):
+            msg_list.append(optGetMessage(option_handle, i + 1))
+
+        raise RuntimeError(
+            f"Error while processing {solver_def_file}. Log messages: {msg_list}"
+        )
+
+    optClearMessages(option_handle)
+
+    # Check the validity of the parameters
+    if optReadParameterFile(option_handle, options_file_name):
+        raise RuntimeError(f"Error while reading {options_file_name}")
+
+    msg_list = []
+    for i in range(optMessageCount(option_handle)):
+        msg_list.append(optGetMessage(option_handle, i + 1))
+
+    optClearMessages(option_handle)
+    optFree(option_handle)
+
+    if msg_list:
+        error_messages = []
+        for message in msg_list:
+            # optMsgInputEcho    = 0,
+            # optMsgHelp         = 1,
+            # optMsgDefineError  = 2,
+            # optMsgValueError   = 3,
+            # optMsgValueWarning = 4,
+            # optMsgDeprecated   = 5,
+            # optMsgFileEnter    = 6,
+            # optMsgFileLeave    = 7,
+            # optMsgTooManyMsgs  = 8,
+            # optMsgUserError    = 9
+            if message[1] not in (6, 7):
+                error_messages.append(message[0])
+
+        if error_messages:
+            error_message = "\n".join(error_messages)
+            raise ValidationError(
+                f"Error while reading the parameter file: \n\n{error_message}"
+            )
