@@ -1,11 +1,14 @@
 import gamspy.formulations.nn as nn
 import gamspy.formulations.piecewise as piecewise
+from gamspy.formulations.ml import DecisionTreeStruct, RegressionTree
 from gamspy.formulations.nn import (
     AvgPool2d,
+    Conv1d,
     Conv2d,
     Linear,
     MaxPool2d,
     MinPool2d,
+    TorchSequential,
 )
 from gamspy.formulations.piecewise import (
     pwl_convexity_formulation,
@@ -15,7 +18,9 @@ from gamspy.formulations.shape import flatten_dims
 
 __all__ = [
     "nn",
+    "ml",
     "piecewise",
+    "Conv1d",
     "Conv2d",
     "MaxPool2d",
     "MinPool2d",
@@ -24,4 +29,7 @@ __all__ = [
     "flatten_dims",
     "pwl_convexity_formulation",
     "pwl_interval_formulation",
+    "RegressionTree",
+    "DecisionTreeStruct",
+    "TorchSequential",
 ]
