@@ -1,15 +1,19 @@
 from gamspy.formulations.nn.avgpool2d import AvgPool2d
+from gamspy.formulations.nn.conv1d import Conv1d
 from gamspy.formulations.nn.conv2d import Conv2d
 from gamspy.formulations.nn.linear import Linear
 from gamspy.formulations.nn.maxpool2d import MaxPool2d
 from gamspy.formulations.nn.minpool2d import MinPool2d
 from gamspy.formulations.nn.mpool2d import _MPool2d
+from gamspy.formulations.nn.torch_sequential import TorchSequential
 
 __all__ = [
+    "Conv1d",
     "Conv2d",
     "_MPool2d",
     "MaxPool2d",
     "MinPool2d",
     "AvgPool2d",
     "Linear",
+    "TorchSequential",
 ]
